% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/HTDoseResponseCurve.R
\name{fit_DRC_synergy}
\alias{fit_DRC_synergy}
\title{Attempt to fit multiple dose-response curves for a range of doses for 
treatment_a, broken out by individual doses of treatment_b.}
\usage{
fit_DRC_synergy(
  ds,
  fct,
  sample_type,
  hour,
  treatment_for_DRC = NA,
  treatment_subgroups,
  concentrations_for_DRC = NA,
  concentrations_subgroups = NA
)
}
\arguments{
\item{ds}{experiment dataset with columns matching the output of 
\code{combine_data_and_map}}

\item{fct}{Non-linear function to fit, e.g. drc::LL.3(). See summary.}

\item{sample_type}{Which sample type (e.g. distinct cell line) of the 
sample types in D will be fit. Unlike fit_DRC, a single sample type must 
be passed.}

\item{hour}{The hour in experiment dataset D at which to fit.}

\item{treatment_for_DRC}{treatment whose values will be used to plot 
individual dose-response curves}

\item{treatment_subgroups}{treatment that will be used to subgroup 
measurements of treatment_for_DRC}

\item{concentrations_for_DRC}{concentrations used for treatment_for_DRC. 
Defaults to NA, use all valid concentrations}

\item{concentrations_subgroups}{concentrations used for treatment_subgroups. 
Defaults to NA, use all valid concentrations}
}
\value{
A list with elements fit, a HT_fit object, and legend_details, a 
data frame that indicates the correspondence between the plot colors that 
will be chosen by default if plot(fit) is called and the concentration of 
treatment_b.
}
\description{
Given a data frame of measurements generated by 
\code{\link{combine_data_and_map}} or matching the format generated by that 
function, fit a dose-response curve for each unique sample_type/treatment 
specified by the sample_types and treatments parameters. A curve will 
be fit for each sample in sample_types, at each treatment in treatments.
}
\details{
If the data are from a synergy experiment, you must specify the concentration
to use for the curve in the concentration_column parameter as one of 
{concentration, concentration_2}.
}
\section{Non-linear function for curve fitting}{


Curve fitting is performed by the \code{drm()} function in the \code{drc} 
library. To fit the curve, you need to select a non-linear function. To 
estimate the slope, upper asymptote, lower asymptote, and EC50, pass 
drc::LL.4(). To fix the lower asymptote at 1 and estimate the other 
parameters, pass drc::LL.3(). To fix the upper asympotote at 1 and the lower 
asymptote at 0, pass drc::LL.2. For a list of available functions, see 
\code{drc::getMeanFunctions()}. 

To call this function you must load the drc package in your R session.
}

