% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/read_write.R
\name{read_platemap_from_excel}
\alias{read_platemap_from_excel}
\title{Read plate maps into a list of three data frames}
\usage{
read_platemap_from_excel(
  filename,
  sheet_num = 1,
  number_of_wells,
  concentration_identifier = "concentration",
  treatment_identifier = "treatment",
  sample_identifier = "cell line",
  concentration_2_identifier = "concentration_2",
  treatment_2_identifier = "treatment_2",
  na.strings = c("", "NA")
)
}
\arguments{
\item{filename}{Excel file generated by the user}

\item{sheet_num}{Index of the Excel sheet to read from filename. Defaults to 
1.}

\item{number_of_wells}{The number of wells in each plate; must be one of 
6, 12, 24, 96, 384.}

\item{concentration_identifier}{Text in a cell in column 1 that signals the 
concentration map will follow. Defaults to "concentration".}

\item{treatment_identifier}{text in a cell in column 1 that signals the 
treatment_identifier map will follow. Defaults to "treatment".}

\item{sample_identifier}{text in a cell in column 1 that signals the 
sample_identifier map will follow. Defaults to "cell line".}

\item{concentration_2_identifier}{Text in a cell in column 1 that signals the 
concentration map will follow for the second treatment. ONLY used if this 
is a synergy (two treatment) experiment. Ignored if there is only one 
treatment per well. Defaults to "concentration_2".}

\item{treatment_2_identifier}{text in a cell in column 1 that signals the 
treatment_identifier map will follow. ONLY used if this is a synergy (two 
treatment) experiment. Ignored if there is only one treatment per well.
Defaults to Defaults to "treatment_2".}

\item{na.strings}{text in a cell that is interpreted as missing data. 
Defaults to the strings "NA" or an empty cell.}
}
\value{
A data frame where columns are data, timestamp, plate_id, hour.
}
\description{
A Plate map describes the cell lines, treatment, and treatment concentrations
applied to each well. As an alternate to exporting a plate map into 
XML directly from the instrument, \code{read_platemap_from_excel} loads plate
map data from an Excel file. The input file must contain cells in column A
indicating the values for treatment concentration in uM (e.g. 0.2 for 200 
nM), treatment (e.g. the drug in a well), and sample type (e.g. the 
identifier for a particular cell line in a well). These cells should be 
one cell up and to the left of plate maps themselves.
}
\examples{
pkg = "HTDoseResponseCurve"
fn_map = system.file("extdata", "sample_data_96_platemap.xlsx",package=pkg)
plate_map = read_platemap_from_excel( fn_map, number_of_wells=96 )
}
